@@ -25,6 +25,7 @@ mod drawing;
 mod font;
 mod grid_span;
 mod header_reference;
+mod footer_reference;
 mod highlight;
 mod indent;
 mod indent_level;
@@ -121,6 +122,7 @@ pub use drawing::*;
 pub use font::*;
 pub use grid_span::*;
 pub use header_reference::*;
+pub use footer_reference::*;
 pub use highlight::*;
 pub use indent::*;
 pub use indent_level::*;
