@@ -167,11 +167,15 @@ impl XMLBuilder {
         before: Option<u32>,
         after: Option<u32>,
         line: Option<u32>,
+        before_lines: Option<u32>,
+        after_lines: Option<u32>,
         spacing: Option<LineSpacingType>,
     ) -> Self {
         let mut xml_event = XmlEvent::start_element("w:spacing");
         let before_val: String;
         let after_val: String;
+        let before_lines_val: String;
+        let after_lines_val: String;
         let line_val: String;
 
         if let Some(before) = before {
@@ -182,6 +186,14 @@ impl XMLBuilder {
             after_val = format!("{}", after);
             xml_event = xml_event.attr("w:after", &after_val)
         }
+        if let Some(before_lines) = before_lines {
+            before_lines_val = format!("{}", before_lines);
+            xml_event = xml_event.attr("w:beforeLines", &before_lines_val)
+        }
+        if let Some(after_lines) = after_lines {
+            after_lines_val = format!("{}", after_lines);
+            xml_event = xml_event.attr("w:afterLines", &after_lines_val)
+        }
         if let Some(line) = line {
             line_val = format!("{}", line);
             xml_event = xml_event.attr("w:line", &line_val)
@@ -262,6 +274,7 @@ impl XMLBuilder {
 
     open!(open_section_property, "w:sectPr");
     closed!(header_reference, "w:headerReference", "w:type", "r:id");
+    closed!(footer_reference, "w:footerReference", "w:type", "r:id");
 
     closed_with_str!(type_tag, "w:type");
     closed!(page_size, "w:pgSz", "w:w", "w:h");
